.. ref-sdb

===
sdb
===

boto.sdb
--------

.. automodule:: boto.sdb
   :members:   
   :undoc-members:

boto.sdb.connection
-------------------

.. automodule:: boto.sdb.connection
   :members:   
   :undoc-members:

boto.sdb.db
-----------

.. automodule:: boto.sdb.db
   :members:   
   :undoc-members:

boto.sdb.db.blob
----------------

.. automodule:: boto.sdb.db.blob
   :members:   
   :undoc-members:

boto.sdb.db.key
---------------

.. automodule:: boto.sdb.db.key
   :members:   
   :undoc-members:

boto.sdb.db.manager
-------------------

.. automodule:: boto.sdb.db.manager
   :members:   
   :undoc-members:

boto.sdb.db.manager.pgmanager
-----------------------------

.. note::

   This module requires psycopg2__ to be installed in the Python path.
   
   __ http://initd.org/

.. automodule:: boto.sdb.db.manager.pgmanager
   :members:   
   :undoc-members:

boto.sdb.db.manager.sdbmanager
------------------------------

.. automodule:: boto.sdb.db.manager.sdbmanager
   :members:   
   :undoc-members:

boto.sdb.db.manager.xmlmanager
------------------------------

.. automodule:: boto.sdb.db.manager.xmlmanager
   :members:   
   :undoc-members:

boto.sdb.db.model
-----------------

.. automodule:: boto.sdb.db.model
   :members:   
   :undoc-members:

boto.sdb.db.property
--------------------

.. automodule:: boto.sdb.db.property
   :members:   
   :undoc-members:

boto.sdb.db.query
-----------------

.. automodule:: boto.sdb.db.query
   :members:   
   :undoc-members:

boto.sdb.domain
---------------

.. automodule:: boto.sdb.domain
   :members:   
   :undoc-members:

boto.sdb.item
-------------

.. automodule:: boto.sdb.item
   :members:   
   :undoc-members:

boto.sdb.persist
----------------

.. automodule:: boto.sdb.persist
   :members:   
   :undoc-members:

boto.sdb.persist.checker
------------------------

.. automodule:: boto.sdb.persist.checker
   :members:   
   :undoc-members:

boto.sdb.persist.object
-----------------------

.. automodule:: boto.sdb.persist.object
   :members:   
   :undoc-members:

boto.sdb.persist.property
-------------------------

.. automodule:: boto.sdb.persist.property
   :members:   
   :undoc-members:

boto.sdb.queryresultset
-----------------------

.. automodule:: boto.sdb.queryresultset
   :members:   
   :undoc-members:
